@@ -1,3 +1,3 @@
 from swem import download, models
 from swem.download import download_w2v
-from swem.models import infer_vector, SWEM
+from swem.models import infer_vector, load_w2v, SWEM
